@@ -49,7 +49,7 @@ char *ABOUT_TEXT[] = {"\nHexxagon v0.3.1\n",
 char aboutStr[4096];
 
 #include <gtk/gtk.h>
-#include <iostream.h>
+#include <iostream>
 #include <strings.h>
 #include <stdlib.h>
 
@@ -58,6 +58,8 @@ char aboutStr[4096];
 #include "rendering.h"
 #include "game.h"
 
+using namespace std;
+
 static void menu_new();
 static void menu_open();
 static void menu_save();
